#
# spec file for package okular
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           okular
Version:        24.05.2
Release:        1.1
Summary:        Document Viewer
# GPL-3.0+ license used by a runtime plugin
License:        GPL-2.0-or-later AND GPL-3.0-or-later
URL:            https://okular.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# PATCH-FEATURE-OPENSUSE
Patch1000:      0001-Inform-users-about-the-okular-spectre-package.patch
# Disabled upstream
# BuildRequires:  chmlib-devel
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libdjvulibre-devel
BuildRequires:  libepub-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmarkdown-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KExiv2Qt6)
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Pty) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6ThreadWeaver) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Phonon4Qt6)
BuildRequires:  cmake(PlasmaActivities)
BuildRequires:  cmake(QMobipocket6)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6TextToSpeech) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(poppler-qt6) >= 22.02.0
BuildRequires:  pkgconfig(zlib)
Suggests:       %{name}-spectre
Obsoletes:      okular5 < %{version}
Provides:       okular5 = %{version}

%description
Document viewing program; supports document in PDF, PS and
many other formats.

%package spectre
Summary:        PostScript support for the Okular document viewer
Requires:       %{name} = %{version}-%{release}

%description spectre
Document viewing program; supports document in PDF, PS and
many other formats. This package contains the plugins required
to display PostScript documents and images.

%package mobile
Summary:        Document Viewer, Mobile UI
Requires:       %{name} = %{version}-%{release}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kirigami-addons6

%description mobile
Document viewing program; supports document in PDF, PS and
many other formats. This contains the UI targeted at mobile devices with a
touch screen.

%package devel
Summary:        Development files for the Okular document viewer
Requires:       %{name} = %{version}
Requires:       cmake(KF6Config) >= %{kf6_version}
Requires:       cmake(KF6CoreAddons) >= %{kf6_version}
Requires:       cmake(KF6XmlGui) >= %{kf6_version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6PrintSupport) >= %{qt6_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}
Obsoletes:      okular5-devel < %{version}
Provides:       okular5-devel = %{version}

%description devel
Document viewing program; supports document in various formats

%lang_package

%prep
%autosetup -p1 -n okular-%{version}

# No technical reason for requiring cmake 3.22
sed -i 's#3.22#3.20#' CMakeLists.txt

%build
%ifarch ppc64
%define _lto_cflags %{nil}
%endif
%cmake_kf6 -DBUILD_TESTING=OFF -DOKULAR_UI=both
%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --with-man --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc %lang(en) %{_kf6_htmldir}/en/*/
%doc %{_kf6_mandir}/man1/okular.*
# %%{_kf6_applicationsdir}/okularApplication_chm.desktop
%{_kf6_applicationsdir}/okularApplication_comicbook.desktop
%{_kf6_applicationsdir}/okularApplication_djvu.desktop
%{_kf6_applicationsdir}/okularApplication_dvi.desktop
%{_kf6_applicationsdir}/okularApplication_epub.desktop
%{_kf6_applicationsdir}/okularApplication_fax.desktop
%{_kf6_applicationsdir}/okularApplication_fb.desktop
%{_kf6_applicationsdir}/okularApplication_kimgio.desktop
%{_kf6_applicationsdir}/okularApplication_md.desktop
%{_kf6_applicationsdir}/okularApplication_mobi.desktop
%{_kf6_applicationsdir}/okularApplication_pdf.desktop
%{_kf6_applicationsdir}/okularApplication_tiff.desktop
%{_kf6_applicationsdir}/okularApplication_txt.desktop
%{_kf6_applicationsdir}/okularApplication_xps.desktop
%{_kf6_applicationsdir}/org.kde.okular.desktop
# %%{_kf6_appstreamdir}/org.kde.okular-chm.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-comicbook.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-djvu.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-dvi.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-epub.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-fax.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-fb.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-kimgio.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-md.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-mobipocket.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-poppler.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-tiff.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-txt.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular-xps.metainfo.xml
%{_kf6_appstreamdir}/org.kde.okular.appdata.xml
%{_kf6_bindir}/okular
%{_kf6_configkcfgdir}/gssettings.kcfg
%{_kf6_configkcfgdir}/okular.kcfg
%{_kf6_configkcfgdir}/okular_core.kcfg
%{_kf6_configkcfgdir}/pdfsettings.kcfg
%{_kf6_debugdir}/okular.categories
%{_kf6_iconsdir}/hicolor/*/*/okular.*
%{_kf6_libdir}/libOkular6Core.so.*
%{_kf6_plugindir}/kf6/parts/okularpart.so
# %%{_kf6_plugindir}/kf6/kio/kio_msits.so
%dir %{_kf6_plugindir}/okular_generators/
# %%{_kf6_plugindir}/okular_generators/okularGenerator_chmlib.so
%{_kf6_plugindir}/okular_generators/okularGenerator_comicbook.so
%{_kf6_plugindir}/okular_generators/okularGenerator_djvu.so
%{_kf6_plugindir}/okular_generators/okularGenerator_dvi.so
%{_kf6_plugindir}/okular_generators/okularGenerator_epub.so
%{_kf6_plugindir}/okular_generators/okularGenerator_fax.so
%{_kf6_plugindir}/okular_generators/okularGenerator_fb.so
%{_kf6_plugindir}/okular_generators/okularGenerator_kimgio.so
%{_kf6_plugindir}/okular_generators/okularGenerator_md.so
%{_kf6_plugindir}/okular_generators/okularGenerator_mobi.so
%{_kf6_plugindir}/okular_generators/okularGenerator_poppler.so
%{_kf6_plugindir}/okular_generators/okularGenerator_tiff.so
%{_kf6_plugindir}/okular_generators/okularGenerator_txt.so
%{_kf6_plugindir}/okular_generators/okularGenerator_xps.so
%{_kf6_sharedir}/kconf_update/okular.upd
%{_kf6_sharedir}/okular/

%files spectre
%{_kf6_applicationsdir}/okularApplication_ghostview.desktop
%{_kf6_appstreamdir}/org.kde.okular-spectre.metainfo.xml
%{_kf6_plugindir}/okular_generators/okularGenerator_ghostview.so

%files mobile
%license LICENSES/*
%{_kf6_bindir}/okularkirigami
%{_kf6_qmldir}/org/kde/okular/
%{_kf6_applicationsdir}/org.kde.okular.kirigami.desktop
# Can use a wildcard here, for non-mobile it's already expanded above
%{_kf6_applicationsdir}/org.kde.mobile.okular_*.desktop
%{_kf6_appstreamdir}/org.kde.okular.kirigami.appdata.xml

%files devel
%{_includedir}/okular/
%{_kf6_cmakedir}/Okular6/
%{_kf6_libdir}/libOkular6Core.so

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/*/

%changelog
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Fix crash on certain pdf actions
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * dvi: Add another check for index to glyphtable being in range
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Unify usage of WITH_K7ZIP
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix sidebar status not being respected when opening the first file (kde#484938)
  * Load certificates delayed (kde#472356)
  * Fix DocumentHasPassword check (kde#474888)
  * Fix crash on closing Annot Window if spell checking is enabled (kde#483904)
  * Fix loading okular preview part (kde#483109)
  * Fix multiline selection (kde#482249)
  * Fix crash when in embedded dummy mode (kde#476207)
  * presentationwidget: Invalidate pixmaps on dpr change (kde#479141)
  * Button groups can span multiple pages (kde#479942)
  * Add support for app.popUpMenu and submenus in popUpMenuEx (kde#479777)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Properly reset documentHasPassword
  * Fix DocumentHasPassword check (kde#474888)
  * Fix crash on closing Annot Window if spell checking is enabled (kde#483904)
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Fix loading okular preview part (kde#483109)
  * Fix configure web shortcuts popup in kcmshell6
  * Fix multiline selection (kde#482249)
  * Fix crash when in embedded dummy mode (kde#476207)
  * Newer clazy: More potential detaching temporary
  * Newer clazy: More PMF
  * Newer clazy: Use PMF for actions
  * Newer clazy: More QListery
  * Newer clazy: Add a few std::as_const
  * Newer clazy: QList changes
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * presentationwidget: Invalidate pixmaps on dpr change (kde#479141)
  * CI test runners are slower
  * Better user strings for signature settings
  * org.kde.okular.appdata: Add developer_name
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Add CI template for building APKs on invent
  * Reflect move of KActivities out of Frameworks to Plasma
  * snapcraft: initial import snapcraft files.
* Mon Oct 30 2023 Antonio Larrosa <alarrosa@suse.com>
- Rework patch that informs the user about missing postscript
  support and how to install it. Replace patch:
  * 0001-Inform-users-about-the-okular-spectre-package-in-the.patch
  with
  * 0001-Inform-users-about-the-okular-spectre-package.patch
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * markdown: Fix rendering with discount3 (kde#475198)
  * CI: fix which clang tidy we want
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix creation of new JS objects (kde#474256)
  * Guard against setting invalid button icons
  * The nFace argument in PDF JS button icon methods is optional
  * Fix cert selection height
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * No need to lookup paths for images without a dot.
  * Better suggested signed name
  * Bump SOVERSION of okularcore
  * Fix playing of external audio files
  * Fix phonon not being correctly detected
  * Fix markdown converter with libdiscount 3
  * Forms: Don't run focusin action when gaining focus because of window management (kde#472756)
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Handle absolute urls in Document::processAction (kde#472440)
  * Avoid accidental scrolling when performing pinch gesture (kde#421755)
  * Surface Digitally Sign action more obviously in hamburger menu (kde#470752)
  * Make default PDF printing scale mode configurable (kde#463732)
  * Let user "Save As..." when document has been externally modified (kde#402017)
  * Reuse an existing action to toggle sidebar visibility (kde#468317)
  * JS: Implement field.valueAsString (kde#468036)
  * Fix crash when executing the Save action (kde#467603)
  * JS: Make field.value return a number if possible (kde#467852)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Bump c++ standard version. Poppler is about to use c++17 types in
    the api, so better be prepared
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Let user "Save As..." when document has been externally modified (kde#402017)
  * Reuse an existing action to toggle sidebar visibility (kde#468317)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Thu Mar 30 2023 Christophe Marin <christophe@krop.fr>
- Drop patch, now unneeded:
  * 0001-Compile-with-discount-3.patch
* Tue Mar 28 2023 Christophe Marin <christophe@krop.fr>
- Add Discount 3 compatibility patch:
  * 0001-Compile-with-discount-3.patch
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * Support SaveAs action (kde#451010)
  * Fix broken page MiniBar (kde#450347)
  * Part::queryClose: Don't ask the user if he wants to save file types
    we can't save (kde#449976)
  * Adds option editor-cmd to the commandline (kde#263732)
  * Simplify the string for the 'Search for...' action (kde#450334)
  * Put an "Add Bookmark" button on the Bookmarks sidebar (kde#357625)
  * Support the PDF Print named action (kde#448791)
  * Remove extra spaces in FB2 paragraphs (kde#359059)
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Fix wrong default font string for annotation tools
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Fix opening epub files with non ascii names on Windows (kde#448274)
  * Make sure helper apps we start are in path
  * XPS: fix multipiece image loading
  * Fix saving to okular archive on Windows (kde#431717)
  * Fix previewing embedded files on Windows (kde#448735)
  * Fix two Signature issues on multipage/multisignature documents
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Fix opening some password protected documents
  * CI: Debian has removed clazy from testing, use the one in unstable for now
  * Fix uninitialized memory read when opening the settings
  * Fix crash when adding stamps to the quick annotations (kde#447409)
  * Make CI happy
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Fix implementation of AFNumber_Format (kde#445868)
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Presentation: Don't hide toolbar if we're not really leaving the window (kde#444427)
  * Fix zoom actions not being updated correctly (kde#440173)
  * okularcore doesn't need dbus
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Markdown: Don't crash on files with html images, alt text, inside links (kde#444971)
  * markdown: Only remove text if we're going to add something (kde#443057)
  * Improve dialog text when asking for annotation author name (kde#442381)
  * Add quick annotation minibar action (kde#425438)
  * Fixed encoding detection for small texts (up to 3000 bytes) (kde#334733)
  * Fix non unique KPlugin Id for fictionbook generator (kde#439807)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Relax the check for non square DPI (kde#444168)
  * Make Quick Annotations button open the full toolbar when no Quick Annotations are configured
  * CI: add the deb-src of testing since we're based on testing not unstable
  * Fix bookmark menu actions missing after switching tabs (kde#442668)
  * util.printd: Don't crash if we get an unexpected oDate argument (kde#443255)
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * markdown: Only remove text if we're going to add something (kde#443057)
  * Automatically enable and disable "Force Rasterization" when required (kde#434247)
  * annotationtoolbartest: Remove unneded cast
  * Don't allow saving over read-only files (kde#440986)
  * Remove \n if it's the last char of the selected text (kde#342874)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Stamps: Fix final showing the expired stamp (kde#441134)
  * textpage: Don't use the page bounding rect as initial text rect
  * CI: silence clazy warning now that there's a new clazy version
* Fri Aug 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto for ppc64 builds.
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.07.90:
  * Take into account the label size while setting size of the page number box.
  * ToggleActionMenu::createWidget(): Do not crash if parent is not a QToolBar
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Fix Page Up/Down scrolling when scrollbars are turned off (kde#421822)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Fixed encoding detection for small texts (up to 3000 bytes) (kde#334733)
  * Fix non unique KPlugin Id for fictionbook generator (kde#439807)
  * CursorWrapHelper: Do not crash on Wayland. (kde#437334)
  * Uncheck mouse mode action when annotation tool selected (kde#398108)
  * Create color mode menu. (kde#407217)
  * doc: Try to make it clearer that one one is used not all three (kde#436820)
  * Uncheck quick annotation when repopulating the quick tools menu (kde#426026)
  * Enable horizontal mouse wrap for Browse tool drag scrolling (kde#371904)
  * Fixes changing continuous mode while on tabs issue (kde#422080)
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Request Pixmaps in slotRelayoutPages
  * Fix signatures.html help:/ url
  * epub: switch epub logs to warning (kde#438490)
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * FormLineEdit: Don't run focusin action when gaining focus because of window management (kde#436990)
  * FormLineEdit: Don't run focusout/formatfield actions when losing focus because of window management (kde#435833)
  * FormLineEdit: Move editing=false up in the focus out event
  * Mark items with name in toolsQuick as default
  * Unbox alert() parameters when they are in an object
  * Second attempt at fixing the windows/craft build
  * Fix spectre includes
  * Fix loading some png files inside zip comicbook files (kde#436086)
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * try to stabilize test
  * Fix saving signed revisions of a signature
  * Fix bug: select browse tool after trim select
  * Fix: Viewport coords normalized w.r.t. full page
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Signature: Don't show "Reason: Not Available" if there's no signing reason
  * Open the signed document on the page with the new signature
  * Slight improvement to signature look&feel
  * partest: Fix one test interfering with the next
  * Don't call i18n before constructing QApplication
  * Fix valgrind warning about uninit variables
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Changes since 21.03.80:
  * Fix a bug with zoom levels on cropped pages (kde#342003)
  * conf: Fix layout warnings
  * Fix playing RichMedia annotations (kde#434962)
  * Fix white background flashing up when using Invert Lightness/Luma (kde#431372)
  * If FB has multiple authors, show them all
  * Add a few more formats supported by qimageformat plugins (kde#434888)
  * Update screenshots in metadata
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * Switch to existing document in new tab by default (kde#432942)
  * Enhance FictionBook support: book annotation, text-author for the cite, section subtitles (kde#340134)
  * Make ESC key leave fullscreen (kde#366276, kde#417337, kde#269677)
  * Use more standard cmake functionality to search for discount (kde#431311)
  * Fix Table Selection polluting clipboard history (kde#402110)
- Enable build the mobile ui for Okular
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * presentation: Show better the status of the "playing" button (kde#432416)
  * pdf: Fix InPlace text annotations being loaded as linked (kde#432009, kde#432932)
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Reload xml to update shortcuts when they change in other parts
  * Fix an unexpected file type being the default on open (non Plasma desktops) (kde#430728)
  * We're using clang format 11 on CI now
  * CI: Switch to new clang-format
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Fix opening markdown files (kde#430538)
  * Make search work on documents that describe Å as A + ◌̊ (kde#430243)
  * Fix crash with some broken PDF files
  * pdf: Fix small memory leak
  * clang-tidy: Disable performance-no-automatic-move
  * Make the CI pass with new clang-tidy
  * Document::openRelativeFile: Double check the url changed when we asked to (kde#429924)
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * handle <subtitle> inside <cite> in FictionBook documents
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * add support for <subtitle> tag in FictionBook
  * Rework how we open urls that have a # (kde#426976)
  * Show annotation tip when selecting the tool in continuous mode (kde#426782)
  * More fine tuning of the mime of the opened file
  * Fix QScroller crash on Qt < 5.14 and certain screen arrangements (kde#425188)
  * Avoid unintentional accelerating flicks by reducing maximum flick time
  * New part/ directory for okularpart sources from /, ui/, conf/
- Rebase 0001-Inform-users-about-the-okular-spectre-package-in-the.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Do not disable flick if cursor has been wrapped (kde#420556)
  * Fix wrong memory access that may cause crash
  * Fix middle click on sidebar tab bar unloads the document. (kde#426613)
  * Support more than latin1 chars on --find command line option (kde#427596)
  * Fix fast scrolling with Shift+Scroll (kde#420889)
  * Fix cursor not updated after clicking internal link (kde#421437)
  * Fix scrolling with scrollbar when the slider is not clicked (kde#421159)
  * Complete TextSelectorEngine if nothing selected (kde#446658)
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Too many changes since 20.08.1, only listing bugfixes:
  * Fix forms when inertially scrolling (kde#421354)
  * Show "Follow link" if right clicking over link and annotation (kde#425291)
  * Fix crash on files that have the same signature in more than 1 page (kde#426467)
  * Restore mouse drag scrolling, so it starts immediately (kde#420842)
  * Re-add smooth scrolling for arrow key and mouse wheel scrolling (kde#422041)
* Wed Sep 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to make the okular-spectre split more user friendly (boo#1176030):
  * 0001-Inform-users-about-the-okular-spectre-package-in-the.patch
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Using no deprecated enum Qt::MiddleButton
  * Improve robustness of code against corrupted configurations
  * Store the state of the builtin annotations in a new config key (kde#425354)
  * buildPen: honor annotation opacity
  * PagePainter: Don't draw Arrow/Line annotations with multipyl (kde#425075)
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * PresentationWidget: Fix screen switching at runtime
  * Find built-in tool corresponding to quick tool at runtime (kde#424810)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Add required Version key to kconf_update file (kde#424616)
  * Test that 'Quick Annotations' is correctly populated
  * Test enabled/disabled state of actions after a config reparsing
  * Test enabled state  of "Quick Annotations" action
  * Ensure "Quick annotations" action is always disabled on protected pdf (kde#424296)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes to list here.
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Increase kjs requirement for using the timeout check
  * allow scaling like 150%% on Windows and default to Breeze style on Windows/macOS
  * Fix/Workaround file where we can't enter values in some fields (kde#421508)
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * allow unicode filenames to work on Windows, too (kde#422500)
  * pdf: fix memory leak when listing fonts
  * Don't attach to another instance if we're going to exit (kde#419982)
  * Fix indentation
  * Fix ZoomIn getting stuck when on facing pages (kde#420824)
  * CI: Remove python-yaml
  * Disable scrolling overshoot (kde#421482)
  * Fix filtering items in the contents treeview (kde#421469)
  * CHM: Fix memory leak every time we open a file
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Fix File menu structure (kde#421004)
  * Fix scroll speed with free-spinning mouse wheels (kde#420492)
  * Fix action collection names of Facing Pages [Center First Page] and Overview
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * djvu: Fix garbage on empty pages at "high" zoom levels (kde#419962)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * CI: Use debian testing while unstable is broken
  * CI: tell debian derivatives not to ask us question in apt time
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * comicbook: Obey autotransform of images (kde#410778)
  * Solving the creation of an additional tab for a deleted file. (kde#412978)
  * Fix crash when not in viewer mode (kde#417118)
  * Fix man page formatting (kde#415468)
  * Document::processAction: If the url points to a binary, don't run it
    (boo#1167435,CVE-2020-9359)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix re-rendering of images when using partial updates (kde#418086)
  * appdata: use canonical cdn screenshot location
  * Fix rendering of stamps with non 100%% opacity
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Fix race condition in generator.cpp
  * Fix render stop and high load due to timing issue (kde#396137)
  * Fix PartTest::testAnnotWindow
  * "Fix" PartTest::testAdditionalActionTriggers
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
  * Fix crash when closing print preview dialog (kde#415340)
  * Fix man page formatting (kde#415468)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Increase version here too
  * Increase version
  * Update Appstream for new release
  * Fix spurious dialogs in PickPointEngine (kde#409638)
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * Remove 'yellow' word (kde#412890)
  * Add "find in this document" to selection context menu (kde#408355)
  * General improvements to stamp annotation (kde#370381)
- Remove obsolete version requirements
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * AnnotWindow: Always show creation time in local time (kde#413591)
  * don't crash on nullptr pdfOptionsPage
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix hi-dpi scaling
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Enhance bounds check in TextDocumentGenerator
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Fix an incorrect text bounding rectangle calculation inside the sidebar
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Fix saving "don't show again" when not using frameworksintegration
  * Partial fix for high res displays (kde#401339)
  * Fix compile with older poppler
  * PDF: Finish support for Optional Content state change links
  * Fix crash for rects that don't have an action
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * [EPubGenerator] Avoid pointless scans of the whole document
  * [EPubGenerator] Avoid crashes due to bogus wrapping of content in table (kde#406738, kde#407140)
  * Revert "Fix build with poppler < 0.51"
  * Fix build with poppler < 0.51
  * Fix line annotation leader line angle
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Fix build with Qt <5.10
  * Fix build with poppler <0.58
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Update version
  * Set Qt::AA_CompressTabletEvents attribute to avoid latency when scrolling with a tablet (kde#399208)
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix MimeType in org.kde.mobile.okular_comicbook.desktop
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Do without em dashes in summaries.
* Thu Jan 31 2019 Luca Beltrame <lbeltrame@kde.org>
- Split Postscript display functionality in a separate subpackage
  (bsc#1117336, boo#1122797)
- List files for plugins, generators, and appstream metadata
  in spec explicitly instead of wildcards
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Do not crash in files without title-info
  * Fix crash when writing to some forms
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix regression in Ctrl+Wheel zoom when using the touchpad
  * Update version for next stable release
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Fix inconsistent viewport positioning in PageView
  * Fix DjVu links pointing to pages with different dimensions
  * Explicitly import Qt 5.7's QtQuick for Connections.enabled
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Add three autotests for part saving
  * Fix saving to files that don't exist
  * Resolve symlinks before saving so we don't "break" them
  * Fix crash if processing a link closes the document
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Fine tune opening of archives after last change
  * Fine tune opening files
  * Avoid undefined behavior due to dangling file descriptor
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix path traversal issue when extracting an .okular file (kde#398096,
    boo#1107591, CVE-2018-1000801)
  * Fix links being "lost" on save (kde#397373)
  * Make sure sorting in the configure backends is always the same
  * Fix problem of saving pdf switches from thumbnail view in sidebar to contents view (kde#389668)
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix properties dialog path not being correct on Save As
  * Increase version
  * Improve picture scaling issues in epub generator
  * Fix crash on shutdown when having edited text forms (kde#396807)
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Do not crash on right-click on TOC item with no associated page
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Force release of free memory
  * Use a target in FindDiscount (modern cmake) rather than variables
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Don't crash if fopen fails
  * Use toLocal8Bit instead of toUtf8
  * Obey umask rules when saving new file (kde#392682)
  * Fix crash on exit when having edited a text area (kde#393334)
  * [Okular] Bug 387282: Highlighting of search results lost when rotating page (kde#387282)
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * [Okular] Bug 387282: Highlighting of search results lost when rotating page (kde#387282)
  * Fix crash in Kile preview mode when enabling fullscreen
  * Use KCrash
  * Fix rubber band selection drawing contents misaligned with scaling
  * increase version to 1.4.x
  * xps: fix file font unloading
  * Fix crash in some more xps files
  * use correct filepath
  * Cancel request when removing an observer
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Tue Mar 27 2018 wbauer@tmo.at
- Add some build requirements to enable additional features:
  * Qt5TextToSpeech for text-to-speech support
  * purpose-devel for enabling the share menu
  * libmarkdown-devel for displaying Markdown documents
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Add QVERIFY to QTest::qWaitForWindowExposed
  * Fix crash due to dangling pointer in MouseAnnotation (kde#388228)
  * Build++
  * Add test that produces bug 388288 crash
  * Make it compile
  * Make Part::openUrl not discard OpenUrlArguments (kde#386600)
  * Fix potential crash in document saving
  * PDF: Fix potential crash
  * XPS: Fix crash opening some files
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Add pdf.gz file save test
  * Fix saving annotations to gzipped files (kde#338742)
  * Fix crash on save when we had edited forms
  * parttest: make the mouse selection be a few steps
  * Use correct arrow cursor for Annotations' close buttons (kde#384381)
  * Improve parttest a bit
  * Fix regression due to more QTemporaryFile behaviour changes
  * Fix crash when exporting
  * djvu: Fix printing
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * remove deprecated Encoding key from desktop files
  * Fix testSaveAsUndoStackAnnotations autotest
  * Don't call m_formsMessage->setVisible( true ) on unsetDummyMode
* Tue Dec 12 2017 lbeltrame@kde.org
- Adjust license after legal review
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Fix crash when accessing text page after save
  * Unbreak compilation of the chm backend
  * We broke ABI by adding a new virtual to generator
  * Increase version now that we're not on unstable versioning anymore
  * Enable -DQT_NO_URL_CAST_FROM_STRING and fix compilation
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Prevent Okular from crashing when synctex logs an error (kde#383915)
  * Change whitespace in synctex patches
  * Fix highlight/annotation clipping with Qt scaling (kde#386110)
  * Give warnings when the file is modified externally
  * generators: Use a specific description for libzip
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix crash on rotation jobs
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Show tooltip for annotations without handle too
  * Properly create KPixmapSequence
  * Fix sidebar labels being unreadable when selected or hovered over (kde#382139)
  * Fix automatic reload of files saved with QSaveFile (kde#384185)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Search for Kirigami
  * CMake: Use some more find_package(... CONFIG)
  * Do not start reloading again if we're reloading
  * Fix crash when closing
  * Fix warning about TRANSLATION_DOMAIN being defined twice
  * Add the base .arcconfig file
  * Fix translations: add translation domain for generators
  * Fix memory leak in text document settings d-pointers
  * Fix width and height being switched when printing Custom size
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * plucker: Comment code to reduce warnings
  * Add a few make gcc lines
  * Fix small warning
  * Make newer gcc happier about fallthrough
  * Add missing break to switch case
  * Fix warning in newer gcc versions
  * 1.2.x for KDE Applications 17.08.x
  * port to Kirigami 2
  * Support Forward and Backward mouse buttons in presentation mode
  * Simplify method FilePrinter::psPaperSize
  * Minor
  * Bug 236688 - Sort pages according to TOC in CHM Files
  * CHM: zooming changes the font size
  * Bug 262265 chmlib should not send qFatal if encoding could not be guessed
  * kio_msits emits mimetype again
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Shell: Fix sync "Show menubar" action status
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Initialize cursor in PageView scrollbars with ArrowCursor (kde#334798)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Don't repeat work of KAboutData::setApplicationData(), set window icon
  * Fix typo
  * Drop unused DBusAddons
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Fix segfault when document is closed while annotation is selected
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * cmake: Remove endif that doesn't match opening if
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * djvu: Initialize to white if rendering fails
  * indent++
  * Accumulate Control+Wheel Deltas until they reach QWheelEvent::DefaultDeltasPerStep
  * Fix crash on CHM files that use "plain English" LCID
  * Account for non local non relative video file urls
  * Extend viewport update area when updating or clearing the a selection rectangle (kde#266537)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Thu Jan 19 2017 wbauer@tmo.at
- Cleanup/update build requirements
- Add necessary dependencies to the devel package (boo#1020735)
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Dropped patches:
  + fix-priority-okular.diff
  + kde4_includes.patch
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
- Drop upstreamed patch mimeinfo17.patch
* Sat Oct  1 2016 wbauer@tmo.at
- Add mimeinfo17.patch to fix opening CBR files with
  shared-mime-info 1.7 (kde#369078)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Mon Jun 27 2016 fvogt@suse.com
- Fix copying of oxygen icons
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Thu Sep 24 2015 alarrosa@suse.com
- Added libqjson-devel to buildrequires
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Mon Aug 10 2015 wbauer@tmo.at
- Replace pkgconfig(exiv2) BuildRequires with pkgconfig(libkexiv2).
  Okular needs to be built against libkexiv2 for image support
  (kimgio plugin), not exiv2.
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Fri Jul 24 2015 nemysis@gmx.ch
- Change URL
- Change Source0 Web URL that works 'osc service localrun download_files'
- Use BuildRequires pkgconfig() instead of devel packages
- Change Description for okular-devel
- Use %%{name} instead of okular
- Change Documentation
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Added kde4_includes.patch: search for includes in standard kde4
  include directory (don't assume it's hardcoded to include/ )
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Thu May  1 2014 hrvoje.senjan@gmail.com
- Added libkscreen-devel BuildRequires, so DPI of current screen
  is used for PDF rendering
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
- Added libkexiv2-devel and mobipocket-devel BuildRequires
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
- Dropped okularcolorbackports.diff, included in this release
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Feb 14 2013 wstephenson@suse.com
- Fix dark-on-dark colour bug when using dark colour schemes
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan 10 2013 tittiatcoke@gmail.com
- Add patch fix-priority-okular.diff to ensure that Okular always
  has a higher priority than the active-documentviewer.
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Drop patch 4_8_branch.diff as it is not used at all
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
- remove upstreamed patch
- add empty 4_8_BRANCH.diff that can be refreshed later
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Fri Nov 11 2011 ctrippe@opensuse.org
- Fix printing with landscape layout (bnc#625122)
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sat Oct  8 2011 toddrme2178@gmail.com
- Added provides for obsoletes (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Mon Sep  5 2011 mlin@suse.com
- add %%fdupes for files duplicated(fix for RPMLINT warnings)
- clean up the specfile format
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Mon Aug  8 2011 mlin@suse.com
- Fixed group for devel package (fix for RPMLINT warning)
- Do not need add standard hierarchy directory: /usr/include in
  files list (fix for RPMLINT warning)
- Use %%{_includedir} macro instead of absolute path /usr/include
- Add version of the dependency requirement for devel package
  (fix for RPMLINT warning)
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Mon Jul  4 2011 idonmez@novell.com
- Update to 4.6.90
* Tue Jun 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110621
* Mon Jun 20 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110620
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Wed Jun 15 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110615
* Tue Jun 14 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110614
* Mon Jun 13 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110613
* Sun Jun 12 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110612
* Sat Jun 11 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110611
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Mon Jun  6 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110606
* Sun Jun  5 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110605
* Sat Jun  4 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110604
* Fri Jun  3 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110603
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Tue May 31 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110531
* Mon May 30 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110530
* Sat May 28 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110528
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110525
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Mon May 23 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110523
* Sat May 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110521
* Fri May 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110520
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Wed May 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110518
* Tue May 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110517
* Mon May 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110516
* Sun May 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110515
* Sat May 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110514
* Fri May 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110513
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Wed May 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110511
* Tue May 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110510
* Mon May  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110509
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Sat May  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110507
* Fri May  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110506
* Thu May  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110505
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Tue May  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110503
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110430
* Fri Apr 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110429
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Fri Apr 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110422
* Thu Apr 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110421
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110419
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sat Apr 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110416
* Fri Apr 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110415
* Thu Apr 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110414
* Wed Apr 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110413
* Tue Apr 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110412
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110411
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to .._20110411
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sat Apr  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110409
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110408
* Thu Apr  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110407
* Wed Apr  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110406
* Tue Apr  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110405
* Mon Apr  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110404
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Wed Sep 15 2010 aj@suse.de
- Change BuildRequires for sane-backends devel split.
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Sat Feb 20 2010 dmueller@suse.de
- tighten library version requires
* Tue Feb  9 2010 dmueller@suse.de
- relax poppler version requirement for more flexibility in
  maintenance updates
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Fri Jan  8 2010 ro@suse.de
- remove imlib from buildrequires (unused)
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Tue Oct 13 2009 beineri@opensuse.org
- only recommend unrar (bnc#546188)
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: translation updates and gwenview fixes
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Thu Aug 20 2009 beineri@opensuse.org
- gwenview: don't let Photography category sneak in from upstream
* Sun Aug 16 2009 beineri@opensuse.org
- remove kolourpaint from Utilities/Editor/ start menu category
* Fri Aug  7 2009 llunak@novell.com
- solid action when pluggin in camera (bnc#505997)
* Thu Aug  6 2009 llunak@suse.cz
- branch update (bnc#528731)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Wed Jul 22 2009 llunak@suse.cz
- epub dependency for okular (bnc#512631)
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu May 14 2009 dmueller@suse.de
- add versioned deps
* Sun May  3 2009 beineri@opensuse.org
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Tue Apr 21 2009 dmueller@suse.de
- rename kde4-gwenview -> gwenview
* Mon Apr 20 2009 dmueller@suse.de
- rename libkexiv2-7-devel to libkexiv2-devel
- rename libkdcraw7-devel to libkdcraw-devel
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Wed Mar 18 2009 dmueller@suse.de
- 4_2_BRANCH.diff:
  * fix gwenview version number
* Tue Mar 10 2009 wstephenson@suse.de
- Add fixed version dependency on libpoppler-qt4-3 to kde4-okular
  to ensure the latest version of libpoppler is installed
  (kde#483753)
* Sat Feb 28 2009 dmueller@suse.de
- build against libqca2 for encrypted document support in okular
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Wed Feb  4 2009 stbinner@suse.de
- require unrar for Okular comic book plugin (bnc#467204)
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Wed Jan 21 2009 stbinner@suse.de
- split off libksane-devel sub-package
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Mon Jan 12 2009 dmueller@suse.de
- rename libkipi6-devel to libkipi-devel
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Fri Nov 28 2008 dmueller@suse.de
- update libkexiv/libkdcraw to trunk for beta6 of digikam
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Wed Nov  5 2008 dmueller@suse.de
- update libkexiv2 / libkdcraw diffs for kde4-digikam
* Tue Nov  4 2008 dmueller@suse.de
- update tarball to final version
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Tue Oct 21 2008 stbinner@suse.de
- branch diff update: gwenview and okular bug fix backports
* Wed Oct  1 2008 dmueller@suse.de
- replace tarball, add libkdcraw upgrade patch to get the same
  code state like before
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Sat Sep 20 2008 stbinner@suse.de
- fix packaging of libksane includes
* Tue Sep  9 2008 dmueller@suse.de
- branch diff update (includes libdcraw6 update for kde4-digikam)
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Tue Aug 19 2008 stbinner@suse.de
- branch diff update: several Okular fixes
* Wed Jul 30 2008 dmueller@suse.de
- update branch diff to fix okular print preview
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Tue Jul  1 2008 dmueller@suse.de
- fix clashing -devel packages
* Mon Jun 30 2008 dmueller@suse.de
- fix filelist
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 25 2008 dmueller@suse.de
- branch diff update
- fix file lists
* Mon Apr 14 2008 dmueller@suse.de
- fix postscript support (bnc#366514)
* Mon Apr  7 2008 dmueller@suse.de
- add qca2 to buildrequires
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 sbrabec@suse.cz
- poppler devel package names prepended by "lib".
* Tue Oct  9 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  9 2007 sbrabec@suse.cz
- Fixed typo in SuSE version check in previous change.
* Mon Oct  8 2007 sbrabec@suse.cz
-  Use binding specific poppler devel package.
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720248
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Fri Sep 21 2007 stbinner@suse.de
- fix gwenview.desktop mime-type definition / SUSEconfig warning
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703909
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700760
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sat Jul 28 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685968
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn678982
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Fri May 25 2007 stbinner@suse.de
- split off -devel package
* Fri May 18 2007 stbinner@suse.de
- initial package in abuild
